+++
[py]
include_code_fences = ["python", ""]
+++

### tangling code with indented code fences

*******************************************************

fences are commented when code

````markdown
```python
print("hello world")
```
````

```python
# ```python
print("hello world")
# ```
```